@@ -1,13 +1,13 @@
 /*
  * commands.c: all the client commands.
  *
- * Copyright(c) 1997,1998 - All Rights Reserved
+ * Copyright(c) 1997,1998,1999 - All Rights Reserved
  *
  * See the COPYRIGHT file.
  */
 
 #ifndef lint
-static char rcsid[] = "@(#)$Id: commands.c,v 1.55 1998/09/03 20:38:07 kalt Exp $";
+static char rcsid[] = "@(#)$Id: commands.c,v 1.57 1999/01/02 22:14:19 kalt Exp $";
 #endif
 
 #include "os.h"
@@ -207,7 +207,7 @@ char *cmd, *p;
       *txt++ = '\0';
       if (rmatch("*@[*]", p))
 	{
-	  char *s = index(p, ']');
+	  char *s = index(index(p, '@'), ']');
 
 	  *s = '\0';
 	  s = index(p, '@');
