@@ -1,13 +1,13 @@
 /*
  * display.c: routines that proceeds the data from a server and format it.
  *
- * Copyright(c) 1997,1998 - All Rights Reserved
+ * Copyright(c) 1997,1998,1999 - All Rights Reserved
  *
  * See the COPYRIGHT file.
  */
 
 #ifndef lint
-static char rcsid[] = "@(#)$Id: display.c,v 1.51 1998/06/25 18:36:35 kalt Exp $";
+static char rcsid[] = "@(#)$Id: display.c,v 1.53 1999/01/02 22:14:19 kalt Exp $";
 #endif
 
 #include "os.h"
@@ -400,6 +400,9 @@ sic_format(sender, cmd, dest, para)
 		  && !get_option(Z_VCTCP, (toch) ? tochannel : NULL))
 		  flags |= LOG_HIDE;
 	    }
+	  if (get_option(Z_URL, (toch) ? tochannel : NULL))
+	      url_find(sender, (toch) ? tochannel : NULL, p);
+
 	  if (!froms && !toch)
 	      if (strncmp("\001DCC ", p, 5))
 		{
