@@ -1,7 +1,7 @@
 /*
  * os.h: getting the OS includes we need with the help of autoconf results
  *
- * Copyright(c) 1997,1998 - All Rights Reserved
+ * Copyright(c) 1997,1998,1999 - All Rights Reserved
  *
  * See the COPYRIGHT file.
  */
@@ -83,3 +83,9 @@ typedef	unsigned int	u_32int_t;
     extern char rx_version_string[];
 # endif
 #endif
+
+#if defined(__NetBSD__)
+# define PUTS_ARG_TYPE (void (*)(int))
+#else
+# define PUTS_ARG_TYPE
+#endif
