@@ -1,13 +1,13 @@
 /*
  * server.c: interactions with servers, tcp code, and DNS resolver
  *
- * Copyright(c) 1997,1998 - All Rights Reserved
+ * Copyright(c) 1997,1998,1999 - All Rights Reserved
  *
  * See the COPYRIGHT file.
  */
 
 #ifndef lint
-static char rcsid[] = "@(#)$Id: server.c,v 1.56 1998/08/31 14:52:29 kalt Exp $";
+static char rcsid[] = "@(#)$Id: server.c,v 1.60 1999/01/02 22:34:19 kalt Exp $";
 #endif
 
 #include "os.h"
@@ -393,11 +393,12 @@ select_server(name)
   struct server_ *stmp = slist;
 
   assert(name);
-  while (stmp && strcasecmp(stmp->sname, name))
+
+  while (stmp && (strcasecmp(stmp->sname, name)
+		  || !option(stmp->sopt, S_CONNECTED)))
       stmp = stmp->nexts;
-  if (stmp && option(stmp->sopt, S_CONNECTED))
-      return server = stmp;
-  return NULL;
+  
+  return server = stmp;
 }
 
 /* sic_server: adds a server to the list, does NOT connect */
@@ -461,7 +462,7 @@ sic_dserver(del)
   if (del->rname)
       free(del->rname);
   if (del->readf)
-      fclose(del->readf);
+      close(del->readf);
   if (del->sendf)
       close(del->sendf);
   free(del);
@@ -813,7 +814,8 @@ sic_select()
 		  if (option(stmp->sopt, S_DCC) && stmp->pass)
 		    { /* file transfer */
 		      if (stmp->readf == NULL)
-			  stmp->readf = fopen(stmp->pass, "w");
+			  stmp->readf = open(stmp->pass,
+					     O_WRONLY|O_TRUNC|O_CREAT, 0644);
 		      if (stmp->readf == NULL)
 			{
 			  vsic_slog(LOG_CLIENT,
@@ -827,8 +829,7 @@ sic_select()
 			{
 			  u_32int_t total; /* DCC ack */
 			  
-			  buf[sz] = '\0';
-			  fprintf(stmp->readf, "%s", buf); /* ugly! */
+			  write(stmp->readf, buf, sz); /* ugly! */
 			  total = htonl(stmp->read += sz);
 			  send(stmp->fd, (char *) &total, sizeof(u_32int_t),0);
 			  if (stmp->read == stmp->size) /* got all of it? */
