@@ -1,5 +1,5 @@
 /*
- * Copyright(c) 1997,1998 - All Rights Reserved
+ * Copyright(c) 1997,1998,1999 - All Rights Reserved
  *
  * See the COPYRIGHT file.
  */
@@ -8,7 +8,11 @@
 # define _term_h_
 
 #ifndef SUNOS_5
-# include <term.h>
+# if defined(HAVE_TERMCAP_H)
+#  include <termcap.h>
+# else
+#  include <term.h>
+# endif /* HAVE_TERMCAP_H */
 #else
 extern	int	tgetent(char *, char *);
 extern	int	tgetnum(char [2]);
@@ -48,7 +52,7 @@ void		term_status(char *, int);
 void		term_input(char *, int);
 
 /* MACROs */
-#define sic_tputs(s)		(tputs(s, 0, putchar))
+#define sic_tputs(s)		(tputs(s, 0, PUTS_ARG_TYPE putchar))
 
 #define term_clear()		(sic_tputs(CL))
 #define term_clreol()		(sic_tputs(CE));
